@@ -16,7 +16,6 @@ export const OPERATOR_TEMPLATE_DIR = 'codeready-workspaces-operator'
 // minimal installable versions by current crwctl
 export const MIN_OLM_INSTALLER_VERSION = '7.17.0'
 export const MIN_CHE_OPERATOR_INSTALLER_VERSION = '7.13.1'
-export const MIN_HELM_INSTALLER_VERSION = '7.10.0'
 
 // labels
 export const CHE_RELATED_COMPONENT_LABEL = 'client/org.eclipse.che=true'
@@ -41,24 +40,33 @@ export const CHE_OPERATOR_SELECTOR = 'app=codeready-operator'
 export const DEFAULT_CHE_NAMESPACE = 'openshift-workspaces'
 export const LEGACY_CHE_NAMESPACE = 'workspaces'
 
-// OLM
+// OLM common
 export const DEFAULT_CHE_OLM_PACKAGE_NAME = 'codeready-workspaces'
+export const DEFAULT_CHE_OPERATOR_SUBSCRIPTION_NAME = 'codeready-subscription'
+export const OPERATOR_GROUP_NAME = 'codeready-operator-group'
+export const CVS_PREFIX = 'crwoperator'
+export const DEVWORKSPACE_CVS_PREFIX = 'crwoperator'
+// OLM channels
 export const OLM_STABLE_CHANNEL_NAME = 'latest'
-export const OLM_NIGHTLY_CHANNEL_NAME = 'nightly'
+export const OLM_STABLE_CHANNEL_STARTING_CSV_TEMPLATE = 'crwoperator.v{{VERSION}}'
+export const OLM_STABLE_ALL_NAMESPACES_CHANNEL_NAME = 'tech-preview-latest-all-namespaces'
+export const OLM_STABLE_ALL_NAMESPACES_CHANNEL_STARTING_CSV_TEMPLATE = 'crwoperatorallnamespaces.v{{VERSION}}'
+export const OLM_NEXT_CHANNEL_NAME = 'next'
+export const OLM_NEXT_ALL_NAMESPACES_CHANNEL_NAME = 'next-all-namespaces'
+// OLM namespaces
 export const DEFAULT_OPENSHIFT_MARKET_PLACE_NAMESPACE = 'openshift-marketplace'
 export const DEFAULT_OLM_KUBERNETES_NAMESPACE = 'olm'
+export const DEFAULT_OPENSHIFT_OPERATORS_NS_NAME = 'openshift-operators'
+// OLM catalogs
 export const CUSTOM_CATALOG_SOURCE_NAME = 'codeready-custom-catalog-source'
-export const SUBSCRIPTION_NAME = 'codeready-subscription'
-export const OPERATOR_GROUP_NAME = 'codeready-operator-group'
+export const NEXT_CATALOG_SOURCE_NAME = 'eclipse-che-preview'
+export const DEFAULT_OLM_SUGGESTED_NAMESPACE = 'openshift-workspaces'
 export const KUBERNETES_OLM_CATALOG = 'operatorhubio-catalog'
 export const OPENSHIFT_OLM_CATALOG = 'redhat-operators'
-export const CVS_PREFIX = 'crwoperator'
-export const NIGHTLY_CATALOG_SOURCE_NAME = 'eclipse-che-preview'
-export const DEFAULT_OLM_SUGGESTED_NAMESPACE = 'openshift-workspaces'
 
 // Documentation links
-export const DOC_LINK = 'https://access.redhat.com/documentation/en-us/red_hat_codeready_workspaces/2.11/'
-export const DOC_LINK_RELEASE_NOTES = 'https://access.redhat.com/documentation/en-us/red_hat_codeready_workspaces/2.11/html/release_notes_and_known_issues/index'
+export const DOC_LINK = 'https://access.redhat.com/documentation/en-us/red_hat_codeready_workspaces/2.14/'
+export const DOC_LINK_RELEASE_NOTES = 'https://access.redhat.com/documentation/en-us/red_hat_codeready_workspaces/2.14/html/release_notes_and_known_issues/index'
 export const DOCS_LINK_INSTALL_RUNNING_CHE_LOCALLY = 'https://www.eclipse.org/che/docs/che-7/installation-guide/installing-che-locally/'
 export const DOCS_LINK_IMPORT_CA_CERT_INTO_BROWSER = 'https://www.eclipse.org/che/docs/che-7/end-user-guide/importing-certificates-to-browsers/'
 export const DOCS_LINK_HOW_TO_ADD_IDENTITY_PROVIDER_OS4 = 'https://docs.openshift.com/container-platform/latest/authentication/understanding-identity-provider.html#identity-provider-overview_understanding-identity-provider'
@@ -76,7 +84,7 @@ export const DEFAULT_ANALYTIC_HOOK_NAME = 'analytics'
 
 // Timeouts
 export const DEFAULT_K8S_POD_WAIT_TIMEOUT = 600000
-export const DEFAULT_K8S_POD_ERROR_RECHECK_TIMEOUT = 15000
+export const DEFAULT_K8S_POD_ERROR_RECHECK_TIMEOUT = 60000
 
 // Custom Resources names
 export const CHE_CLUSTER_CRD = 'checlusters.org.eclipse.che'
@@ -90,3 +98,5 @@ export const CHE_CLUSTER_BACKUP_CRD = 'checlusterbackups.org.eclipse.che'
 export const CHE_CLUSTER_BACKUP_KIND_PLURAL = 'checlusterbackups'
 export const CHE_CLUSTER_RESTORE_CRD = 'checlusterrestores.org.eclipse.che'
 export const CHE_CLUSTER_RESTORE_KIND_PLURAL = 'checlusterrestores'
+
+export const DEFAULT_CHE_TLS_SECRET_NAME = 'che-tls'
