@@ -11,14 +11,14 @@
  */
 
 import * as fs from 'fs-extra'
+import * as os from 'os'
 import * as Listr from 'listr'
 import * as path from 'path'
-
 import { CheHelper } from '../../api/che'
 import { KubeHelper } from '../../api/kube'
-import { V1Certificate } from '../../api/typings/cert-manager'
-import { CA_CERT_GENERATION_JOB_IMAGE, CERT_MANAGER_NAMESPACE_NAME, CHE_RELATED_COMPONENT_LABEL, CHE_ROOT_CA_SECRET_NAME, CHE_TLS_SECRET_NAME } from '../../constants'
-import { base64Decode } from '../../util'
+import { V1Certificate } from '../../api/types/cert-manager'
+import { CA_CERT_GENERATION_JOB_IMAGE, CERT_MANAGER_NAMESPACE_NAME, CHE_RELATED_COMPONENT_LABEL, CHE_ROOT_CA_SECRET_NAME, CHE_TLS_SECRET_NAME, DEFAULT_CA_CERT_FILE_NAME } from '../../constants'
+import { base64Decode, getEmbeddedTemplatesDirectory } from '../../util'
 import { getMessageImportCaCertIntoBrowser } from '../installers/common-tasks'
 
 export const CERT_MANAGER_CA_SECRET_NAME = 'ca'
@@ -37,7 +37,7 @@ export class CertManagerTasks {
   /**
    * Verify if cert-manager is installed in cluster
    */
-  getDeployCertManagerTasks(flags: any): ReadonlyArray<Listr.ListrTask> {
+  getDeployCertManagerTasks(): ReadonlyArray<Listr.ListrTask> {
     return [
       {
         title: 'Check Cert Manager deployment',
@@ -52,15 +52,11 @@ export class CertManagerTasks {
         },
       },
       {
-        title: 'Deploy cert-manager',
+        title: 'Deploy Cert Manager',
         enabled: ctx => !ctx.certManagerInstalled,
         task: async (ctx: any, task: any) => {
-          let yamlPath = path.join(flags.templates, 'cert-manager', 'cert-manager.yaml')
-          if (!await fs.pathExists(yamlPath)) {
-            // Older Che versions don't have Cert Manager install yaml in templates
-            // Try to use embedded in crwctl version
-            yamlPath = path.join(__dirname, '../../../installers/cert-manager.yml')
-          }
+          const yamlPath = path.join(getEmbeddedTemplatesDirectory(), '..', 'resources', 'cert-manager', 'cert-manager.yml')
+
           // Apply additional --validate=false flag to be able to deploy Cert Manager on Kubernetes v1.15.4 or below
           await this.kubeHelper.applyResource(yamlPath, '--validate=false')
           ctx.certManagerInstalled = true
@@ -69,7 +65,7 @@ export class CertManagerTasks {
         },
       },
       {
-        title: 'Wait for cert-manager',
+        title: 'Wait for Cert Manager',
         enabled: ctx => ctx.certManagerInstalled,
         task: async (ctx: any, task: any) => {
           if (!ctx.certManagerInstalled) {
@@ -89,10 +85,7 @@ export class CertManagerTasks {
     ]
   }
 
-  /**
-   * Returns list of tasks which perform cert-manager checks and requests self-signed certificate for Che.
-   */
-  getGenerateCertificatesTasks(flags: any): ReadonlyArray<Listr.ListrTask> {
+  getGenerateCertManagerCACertificateTasks(): ReadonlyArray<Listr.ListrTask> {
     return [
       {
         title: 'Check Cert Manager CA certificate',
@@ -112,8 +105,8 @@ export class CertManagerTasks {
             try {
               // Configure permissions for CA key pair generation job
               await this.kubeHelper.createServiceAccount(CA_CERT_GENERATION_SERVICE_ACCOUNT_NAME, CERT_MANAGER_NAMESPACE_NAME)
-              await this.kubeHelper.createRoleFromFile(path.join(flags.templates, 'cert-manager', 'ca-cert-generator-role.yml'), CERT_MANAGER_NAMESPACE_NAME)
-              await this.kubeHelper.createRoleBindingFromFile(path.join(flags.templates, 'cert-manager', 'ca-cert-generator-role-binding.yml'), CERT_MANAGER_NAMESPACE_NAME)
+              await this.kubeHelper.createRoleFromFile(path.join(getEmbeddedTemplatesDirectory(), '..', 'resources', 'cert-manager', 'ca-cert-generator-role.yml'), CERT_MANAGER_NAMESPACE_NAME)
+              await this.kubeHelper.createRoleBindingFromFile(path.join(getEmbeddedTemplatesDirectory(), '..', 'resources', 'cert-manager', 'ca-cert-generator-role-binding.yml'), CERT_MANAGER_NAMESPACE_NAME)
 
               // Await created resources to be available
               await this.kubeHelper.waitServiceAccount(CA_CERT_GENERATION_SERVICE_ACCOUNT_NAME, CERT_MANAGER_NAMESPACE_NAME)
@@ -148,6 +141,11 @@ export class CertManagerTasks {
           }
         },
       },
+    ]
+  }
+
+  getCreateCertificateIssuerTasks(): ReadonlyArray<Listr.ListrTask> {
+    return [
       {
         title: 'Set up CodeReady Workspaces certificates issuer',
         task: async (ctx: any, task: any) => {
@@ -173,7 +171,7 @@ export class CertManagerTasks {
           ctx.clusterIssuersName = DEFAULT_CHE_CLUSTER_ISSUER_NAME
           const cheClusterIssuerExists = await this.kubeHelper.clusterIssuerExists(DEFAULT_CHE_CLUSTER_ISSUER_NAME, ctx.certManagerK8sApiVersion)
           if (!cheClusterIssuerExists) {
-            const cheCertificateClusterIssuerTemplatePath = path.join(flags.templates, '/cert-manager/che-cluster-issuer.yml')
+            const cheCertificateClusterIssuerTemplatePath = path.join(getEmbeddedTemplatesDirectory(), '..', 'resources', 'cert-manager', 'che-cluster-issuer.yml')
             await this.kubeHelper.createCheClusterIssuer(cheCertificateClusterIssuerTemplatePath, ctx.certManagerK8sApiVersion)
 
             task.title = `${task.title}...done`
@@ -182,8 +180,18 @@ export class CertManagerTasks {
           }
         },
       },
+    ]
+  }
+
+  getGenerateCertificatesTasks(
+    flags: any,
+    commonName: string,
+    dnsNames: string[],
+    secretName: string,
+    namespace: string): ReadonlyArray<Listr.ListrTask> {
+    return [
       {
-        title: 'Request certificate',
+        title: `Request certificate for dnsNames: [${dnsNames}]`,
         task: async (ctx: any, task: any) => {
           if (ctx.cheCertificateExists) {
             throw new Error('CodeReady Workspaces certificate already exists.')
@@ -192,19 +200,15 @@ export class CertManagerTasks {
             task.title = 'Request self-signed certificate'
           }
 
-          const certificateTemplatePath = path.join(flags.templates, '/cert-manager/che-certificate.yml')
-          const certifiateYaml = this.kubeHelper.safeLoadFromYamlFile(certificateTemplatePath) as V1Certificate
+          const certificateTemplatePath = path.join(getEmbeddedTemplatesDirectory(), '..', 'resources', 'cert-manager', 'che-certificate.yml')
+          const certificate = this.kubeHelper.safeLoadFromYamlFile(certificateTemplatePath) as V1Certificate
+          certificate.metadata.namespace = namespace
+          certificate.spec.secretName = secretName
+          certificate.spec.commonName = commonName
+          certificate.spec.dnsNames = dnsNames
+          certificate.spec.issuerRef.name = ctx.clusterIssuersName
 
-          const CN = '*.' + flags.domain
-          certifiateYaml.spec.commonName = CN
-          certifiateYaml.spec.dnsNames = [flags.domain, CN]
-          if (ctx.clusterIssuersName) {
-            certifiateYaml.spec.issuerRef.name = ctx.clusterIssuersName
-          }
-
-          certifiateYaml.metadata.namespace = flags.chenamespace
-
-          await this.kubeHelper.createCheClusterCertificate(certifiateYaml, ctx.certManagerK8sApiVersion)
+          await this.kubeHelper.createCheClusterCertificate(certificate, ctx.certManagerK8sApiVersion)
           ctx.cheCertificateExists = true
 
           task.title = `${task.title}...done`
@@ -216,12 +220,15 @@ export class CertManagerTasks {
           if (ctx.clusterIssuersName === DEFAULT_CHE_CLUSTER_ISSUER_NAME) {
             task.title = 'Wait for self-signed certificate'
           }
-
-          await this.kubeHelper.waitSecret(CHE_TLS_SECRET_NAME, flags.chenamespace, ['tls.key', 'tls.crt', 'ca.crt'])
-
+          await this.kubeHelper.waitSecret(secretName, namespace, ['tls.key', 'tls.crt', 'ca.crt'])
           task.title = `${task.title}...ready`
         },
       },
+    ]
+  }
+
+  getRetrieveCheCACertificate(flags: any): ReadonlyArray<Listr.ListrTask> {
+    return [
       {
         title: 'Retrieving Che CA certificate',
         task: async (ctx: any, task: any) => {
@@ -232,14 +239,15 @@ export class CertManagerTasks {
           const cheSecret = await this.kubeHelper.getSecret(CHE_TLS_SECRET_NAME, flags.chenamespace)
           if (cheSecret && cheSecret.data) {
             const cheCaCrt = base64Decode(cheSecret.data['ca.crt'])
-            const cheCaCertPath = await this.cheHelper.saveCheCaCert(cheCaCrt)
+            const caCertFilePath = path.join(os.tmpdir(), DEFAULT_CA_CERT_FILE_NAME)
+            fs.writeFileSync(caCertFilePath, cheCaCrt)
 
             // We need to put self-signed CA certificate separately into CHE_ROOT_CA_SECRET_NAME secret
             await this.kubeHelper.createSecret(flags.chenamespace, CHE_ROOT_CA_SECRET_NAME, { 'ca.crt': cheCaCrt })
 
             const serverStrategy = await this.kubeHelper.getConfigMapValue('che', flags.chenamespace, 'CHE_INFRA_KUBERNETES_SERVER__STRATEGY')
             if (serverStrategy !== 'single-host') {
-              ctx.highlightedMessages.push(getMessageImportCaCertIntoBrowser(cheCaCertPath))
+              ctx.highlightedMessages.push(getMessageImportCaCertIntoBrowser(caCertFilePath))
             }
             task.title = `${task.title}... done`
           } else {
