@@ -20,7 +20,7 @@ import { CheHelper } from '../../api/che'
 import { KubeHelper } from '../../api/kube'
 import { CatalogSource, Subscription } from '../../api/types/olm'
 import { VersionHelper } from '../../api/version'
-import { CUSTOM_CATALOG_SOURCE_NAME, CVS_PREFIX, DEFAULT_CHE_NAMESPACE, DEFAULT_CHE_OLM_PACKAGE_NAME, DEFAULT_OLM_KUBERNETES_NAMESPACE, DEFAULT_OPENSHIFT_MARKET_PLACE_NAMESPACE, DEFAULT_OPENSHIFT_OPERATORS_NS_NAME, KUBERNETES_OLM_CATALOG, NEXT_CATALOG_SOURCE_NAME, OLM_NEXT_CHANNEL_NAME, OLM_STABLE_CHANNEL_NAME, OPENSHIFT_OLM_CATALOG, OPERATOR_GROUP_NAME, OLM_STABLE_ALL_NAMESPACES_CHANNEL_NAME, DEFAULT_CHE_OPERATOR_SUBSCRIPTION_NAME, OLM_NEXT_ALL_NAMESPACES_CHANNEL_NAME } from '../../constants'
+import { CUSTOM_CATALOG_SOURCE_NAME, CVS_PREFIX, DEFAULT_CHE_NAMESPACE, DEFAULT_CHE_OLM_PACKAGE_NAME, DEFAULT_OLM_KUBERNETES_NAMESPACE, DEFAULT_OPENSHIFT_MARKET_PLACE_NAMESPACE, DEFAULT_OPENSHIFT_OPERATORS_NS_NAME, KUBERNETES_OLM_CATALOG, NEXT_CATALOG_SOURCE_NAME, OLM_NEXT_CHANNEL_NAME, OLM_STABLE_CHANNEL_NAME, OPENSHIFT_OLM_CATALOG, OPERATOR_GROUP_NAME, OLM_STABLE_ALL_NAMESPACES_CHANNEL_NAME, DEFAULT_CHE_OPERATOR_SUBSCRIPTION_NAME, OLM_NEXT_ALL_NAMESPACES_CHANNEL_NAME, OLM_STABLE_CHANNEL_STARTING_CSV_TEMPLATE, OLM_STABLE_ALL_NAMESPACES_CHANNEL_STARTING_CSV_TEMPLATE } from '../../constants'
 import { getEmbeddedTemplatesDirectory, isKubernetesPlatformFamily } from '../../util'
 
 import { createEclipseCheCluster, patchingEclipseCheCluster } from './common-tasks'
@@ -34,7 +34,6 @@ export const TASK_TITLE_DELETE_NIGHTLY_CATALOG_SOURCE = `Delete(OLM) nigthly cat
 
 export class OLMTasks {
   prometheusRoleName = 'prometheus-k8s'
-
   prometheusRoleBindingName = 'prometheus-k8s'
 
   /**
@@ -43,37 +42,9 @@ export class OLMTasks {
   startTasks(flags: any, command: Command): Listr.ListrTask<any>[] {
     const kube = new KubeHelper(flags)
     const che = new CheHelper(flags)
+
     return [
       this.isOlmPreInstalledTask(command, kube),
-      {
-        enabled: () => flags['cluster-monitoring'] && flags.platform === 'openshift',
-        title: `Create Role ${this.prometheusRoleName} in namespace ${flags.chenamespace}`,
-        task: async (_ctx: any, task: any) => {
-          const yamlFilePath = path.join(getEmbeddedTemplatesDirectory(), '..', 'resources', 'prometheus-role.yaml')
-          const exist = await kube.roleExist(this.prometheusRoleName, flags.chenamespace)
-          if (exist) {
-            task.title = `${task.title}...It already exists.`
-          } else {
-            await kube.createRoleFromFile(yamlFilePath, flags.chenamespace)
-            task.title = `${task.title}...done.`
-          }
-        },
-      },
-      {
-        enabled: () => flags['cluster-monitoring'] && flags.platform === 'openshift',
-        title: `Create RoleBinding ${this.prometheusRoleBindingName} in namespace ${flags.chenamespace}`,
-        task: async (_ctx: any, task: any) => {
-          const exist = await kube.roleBindingExist(this.prometheusRoleBindingName, flags.chenamespace)
-          const yamlFilePath = path.join(getEmbeddedTemplatesDirectory(), '..', 'resources', 'prometheus-role-binding.yaml')
-
-          if (exist) {
-            task.title = `${task.title}...It already exists.`
-          } else {
-            await kube.createRoleBindingFromFile(yamlFilePath, flags.chenamespace)
-            task.title = `${task.title}...done.`
-          }
-        },
-      },
       {
         title: 'Configure context information',
         task: async (ctx: any, task: any) => {
@@ -96,25 +67,51 @@ export class OLMTasks {
             if (flags[OLM.STARTING_CSV]) {
               ctx.startingCSV = flags[OLM.STARTING_CSV]
             } else if (flags[OLM.CHANNEL] === OLM_STABLE_CHANNEL_NAME) {
-              ctx.startingCSV = `eclipse-che.v${flags.version}`
+              ctx.startingCSV = OLM_STABLE_CHANNEL_STARTING_CSV_TEMPLATE.replace(new RegExp('{{VERSION}}', 'g'), flags.version)
             } else if (flags[OLM.CHANNEL] === OLM_STABLE_ALL_NAMESPACES_CHANNEL_NAME) {
-              ctx.startingCSV = `eclipse-che-preview-openshift.v${flags.version}-all-namespaces`
+              ctx.startingCSV = OLM_STABLE_ALL_NAMESPACES_CHANNEL_STARTING_CSV_TEMPLATE.replace(new RegExp('{{VERSION}}', 'g'), flags.version)
             } // else use latest in the channel
             // Set approval starategy to manual to prevent autoupdate to the latest version right before installation
-            ctx.approvalStarategy = OLMInstallationUpdate.MANUAL
+            ctx.approvalStrategy = OLMInstallationUpdate.MANUAL
           } else {
             ctx.startingCSV = flags[OLM.STARTING_CSV]
             if (ctx.startingCSV) {
               // Ignore auto-update flag, otherwise it will automatically update to the latest version and 'starting-csv' will not have any effect.
-              ctx.approvalStarategy = OLMInstallationUpdate.MANUAL
+              ctx.approvalStrategy = OLMInstallationUpdate.MANUAL
             } else if (flags[OLM.AUTO_UPDATE] === undefined) {
-              ctx.approvalStarategy = OLMInstallationUpdate.AUTO
+              ctx.approvalStrategy = OLMInstallationUpdate.AUTO
             } else {
-              ctx.approvalStarategy = flags[OLM.AUTO_UPDATE] ? OLMInstallationUpdate.AUTO : OLMInstallationUpdate.MANUAL
+              ctx.approvalStrategy = flags[OLM.AUTO_UPDATE] ? OLMInstallationUpdate.AUTO : OLMInstallationUpdate.MANUAL
             }
           }
 
-          task.title = `${task.title}...done.`
+          task.title = `${task.title}...[OK]`
+        },
+      },
+      {
+        enabled: () => flags['cluster-monitoring'] && flags.platform === 'openshift',
+        title: `Create Role ${this.prometheusRoleName} in namespace ${flags.chenamespace}`,
+        task: async (_ctx: any, task: any) => {
+          if (await kube.isRoleExist(this.prometheusRoleName, flags.chenamespace)) {
+            task.title = `${task.title}...[Exists]`
+          } else {
+            const yamlFilePath = path.join(getEmbeddedTemplatesDirectory(), '..', 'resources', 'prometheus-role.yaml')
+            await kube.createRoleFromFile(yamlFilePath, flags.chenamespace)
+            task.title = `${task.title}...[OK].`
+          }
+        },
+      },
+      {
+        enabled: () => flags['cluster-monitoring'] && flags.platform === 'openshift',
+        title: `Create RoleBinding ${this.prometheusRoleBindingName} in namespace ${flags.chenamespace}`,
+        task: async (_ctx: any, task: any) => {
+          if (await kube.isRoleBindingExist(this.prometheusRoleBindingName, flags.chenamespace)) {
+            task.title = `${task.title}...[Exists]`
+          } else {
+            const yamlFilePath = path.join(getEmbeddedTemplatesDirectory(), '..', 'resources', 'prometheus-role-binding.yaml')
+            await kube.createRoleBindingFromFile(yamlFilePath, flags.chenamespace)
+            task.title = `${task.title}...[OK]`
+          }
         },
       },
       {
@@ -122,12 +119,11 @@ export class OLMTasks {
         // 'stable-all-namespaces' and 'next-all-namespaces' channels install the operator in openshift-operators namespace and there already exists a pre-created operator-group.
         enabled: (ctx: any) => ctx.operatorNamespace !== DEFAULT_OPENSHIFT_OPERATORS_NS_NAME,
         task: async (_ctx: any, task: any) => {
-          const operatorGroup = await che.findCheOperatorOperatorGroup(flags.chenamespace)
-          if (operatorGroup) {
-            task.title = `${task.title}...it already exists: ${operatorGroup.metadata.name}`
+          if (await che.findCheOperatorOperatorGroup(flags.chenamespace)) {
+            task.title = `${task.title}...[Exists]`
           } else {
             await kube.createOperatorGroup(OPERATOR_GROUP_NAME, flags.chenamespace)
-            task.title = `${task.title}...created a new one: ${OPERATOR_GROUP_NAME}`
+            task.title = `${task.title}...[OK]`
           }
         },
       },
@@ -135,13 +131,14 @@ export class OLMTasks {
         enabled: () => !VersionHelper.isDeployingStableVersion(flags) && !flags[OLM.CATALOG_SOURCE_NAME] && !flags[OLM.CATALOG_SOURCE_YAML] && flags[OLM.CHANNEL] !== OLM_STABLE_CHANNEL_NAME,
         title: 'Create next index CatalogSource',
         task: async (ctx: any, task: any) => {
-          if (!await kube.catalogSourceExists(NEXT_CATALOG_SOURCE_NAME, ctx.operatorNamespace)) {
-            const catalogSourceImage = `quay.io/eclipse/eclipse-che-${ctx.generalPlatformName}-opm-catalog:preview`
+          if (!await kube.IsCatalogSourceExists(NEXT_CATALOG_SOURCE_NAME, ctx.operatorNamespace)) {
+            const catalogSourceImage = `quay.io/eclipse/eclipse-che-${ctx.generalPlatformName}-opm-catalog:next`
             const nextCatalogSource = this.constructIndexCatalogSource(ctx.operatorNamespace, catalogSourceImage)
             await kube.createCatalogSource(nextCatalogSource)
             await kube.waitCatalogSource(ctx.operatorNamespace, NEXT_CATALOG_SOURCE_NAME)
+            task.title = `${task.title}...[OK]`
           } else {
-            task.title = `${task.title}...It already exists.`
+            task.title = `${task.title}...[Exists]`
           }
         },
       },
@@ -150,14 +147,14 @@ export class OLMTasks {
         enabled: () => flags[OLM.CATALOG_SOURCE_YAML],
         task: async (ctx: any, task: any) => {
           const customCatalogSource: CatalogSource = kube.readCatalogSourceFromFile(flags[OLM.CATALOG_SOURCE_YAML])
-          if (!await kube.catalogSourceExists(customCatalogSource.metadata!.name!, flags.chenamespace)) {
+          if (!await kube.IsCatalogSourceExists(customCatalogSource.metadata!.name!, flags.chenamespace)) {
             customCatalogSource.metadata.name = ctx.sourceName
             customCatalogSource.metadata.namespace = flags.chenamespace
             await kube.createCatalogSource(customCatalogSource)
             await kube.waitCatalogSource(flags.chenamespace, CUSTOM_CATALOG_SOURCE_NAME)
-            task.title = `${task.title}...created new one, with name ${CUSTOM_CATALOG_SOURCE_NAME} in the namespace ${flags.chenamespace}.`
+            task.title = `${task.title}...[OK: ${CUSTOM_CATALOG_SOURCE_NAME}]`
           } else {
-            task.title = `${task.title}...It already exists.`
+            task.title = `${task.title}...[Exists]`
           }
         },
       },
@@ -167,7 +164,7 @@ export class OLMTasks {
           let subscription = await che.findCheOperatorSubscription(ctx.operatorNamespace)
           if (subscription) {
             ctx.subscriptionName = subscription.metadata.name
-            task.title = `${task.title}...It already exists.`
+            task.title = `${task.title}...[Exists]`
             return
           }
           ctx.subscriptionName = DEFAULT_CHE_OPERATOR_SUBSCRIPTION_NAME
@@ -176,18 +173,18 @@ export class OLMTasks {
           if (flags[OLM.CATALOG_SOURCE_YAML] || flags[OLM.CATALOG_SOURCE_NAME]) {
             // custom Che CatalogSource
             const catalogSourceNamespace = flags[OLM.CATALOG_SOURCE_NAMESPACE] || ctx.operatorNamespace
-            subscription = this.constructSubscription(ctx.subscriptionName, flags[OLM.PACKAGE_MANIFEST_NAME], ctx.operatorNamespace, catalogSourceNamespace, channel || OLM_STABLE_CHANNEL_NAME, ctx.sourceName, ctx.approvalStarategy, ctx.startingCSV)
+            subscription = this.constructSubscription(ctx.subscriptionName, flags[OLM.PACKAGE_MANIFEST_NAME], ctx.operatorNamespace, catalogSourceNamespace, channel || OLM_STABLE_CHANNEL_NAME, ctx.sourceName, ctx.approvalStrategy, ctx.startingCSV)
           } else if (channel === OLM_STABLE_CHANNEL_NAME || channel === OLM_STABLE_ALL_NAMESPACES_CHANNEL_NAME || (VersionHelper.isDeployingStableVersion(flags) && !channel)) {
             // stable Che CatalogSource
-            subscription = this.constructSubscription(ctx.subscriptionName, DEFAULT_CHE_OLM_PACKAGE_NAME, ctx.operatorNamespace, ctx.defaultCatalogSourceNamespace, channel || OLM_STABLE_CHANNEL_NAME, ctx.catalogSourceNameStable, ctx.approvalStarategy, ctx.startingCSV)
+            subscription = this.constructSubscription(ctx.subscriptionName, DEFAULT_CHE_OLM_PACKAGE_NAME, ctx.operatorNamespace, ctx.defaultCatalogSourceNamespace, channel || OLM_STABLE_CHANNEL_NAME, ctx.catalogSourceNameStable, ctx.approvalStrategy, ctx.startingCSV)
           } else if (channel === OLM_NEXT_CHANNEL_NAME || channel === OLM_NEXT_ALL_NAMESPACES_CHANNEL_NAME || !channel) {
             // next Che CatalogSource
-            subscription = this.constructSubscription(ctx.subscriptionName, `eclipse-che-preview-${ctx.generalPlatformName}`, ctx.operatorNamespace, ctx.operatorNamespace, channel || OLM_NEXT_CHANNEL_NAME, NEXT_CATALOG_SOURCE_NAME, ctx.approvalStarategy, ctx.startingCSV)
+            subscription = this.constructSubscription(ctx.subscriptionName, `eclipse-che-preview-${ctx.generalPlatformName}`, ctx.operatorNamespace, ctx.operatorNamespace, channel || OLM_NEXT_CHANNEL_NAME, NEXT_CATALOG_SOURCE_NAME, ctx.approvalStrategy, ctx.startingCSV)
           } else {
             throw new Error(`Unknown OLM channel ${flags[OLM.CHANNEL]}`)
           }
           await kube.createOperatorSubscription(subscription)
-          task.title = `${task.title}...created new one.`
+          task.title = `${task.title}...[OK]`
         },
       },
       {
@@ -195,22 +192,15 @@ export class OLMTasks {
         task: async (ctx: any, task: any) => {
           const installPlan = await kube.waitOperatorSubscriptionReadyForApproval(ctx.operatorNamespace, ctx.subscriptionName, 600)
           ctx.installPlanName = installPlan.name
-          task.title = `${task.title}...done.`
+          task.title = `${task.title}...[OK]`
         },
       },
       {
         title: 'Approve installation',
-        enabled: ctx => ctx.approvalStarategy === OLMInstallationUpdate.MANUAL,
+        enabled: ctx => ctx.approvalStrategy === OLMInstallationUpdate.MANUAL,
         task: async (ctx: any, task: any) => {
           await kube.approveOperatorInstallationPlan(ctx.installPlanName, ctx.operatorNamespace)
-          task.title = `${task.title}...done.`
-        },
-      },
-      {
-        title: 'Wait while operator installed',
-        task: async (ctx: any, task: any) => {
-          await kube.waitUntilOperatorIsInstalled(ctx.installPlanName, ctx.operatorNamespace)
-          task.title = `${task.title}...done.`
+          task.title = `${task.title}...[OK]`
         },
       },
       {
@@ -224,7 +214,14 @@ export class OLMTasks {
           const csv = csvList.items[0]
           const jsonPatch = [{ op: 'replace', path: '/spec/install/spec/deployments/0/spec/template/spec/containers/0/image', value: flags['che-operator-image'] }]
           await kube.patchClusterServiceVersion(csv.metadata.namespace!, csv.metadata.name!, jsonPatch)
-          task.title = `${task.title}... changed to ${flags['che-operator-image']}.`
+          task.title = `${task.title}...[OK]`
+        },
+      },
+      {
+        title: 'Wait while operator installed',
+        task: async (ctx: any, task: any) => {
+          await kube.waitUntilOperatorIsInstalled(ctx.installPlanName, ctx.operatorNamespace)
+          task.title = `${task.title}...[OK]`
         },
       },
       {
@@ -232,7 +229,7 @@ export class OLMTasks {
         task: async (ctx: any, task: any) => {
           const cheCluster = await kube.getCheCluster(flags.chenamespace)
           if (cheCluster) {
-            task.title = `${task.title}...It already exists..`
+            task.title = `${task.title}...[Exists]`
             return
           }
 
@@ -240,7 +237,7 @@ export class OLMTasks {
             ctx.defaultCR = await this.getCRFromCSV(kube, ctx.operatorNamespace, ctx.subscriptionName)
           }
 
-          task.title = `${task.title}...Done.`
+          task.title = `${task.title}...[OK]`
         },
       },
       createEclipseCheCluster(flags, kube),
@@ -260,7 +257,7 @@ export class OLMTasks {
             command.error('Unable to find operator subscription')
           }
           ctx.operatorNamespace = subscription.metadata.namespace
-          task.title = `${task.title}...done.`
+          task.title = `${task.title}...[OK]`
         },
       },
     ], { renderer: flags['listr-renderer'] as any })
@@ -294,7 +291,7 @@ export class OLMTasks {
               const installCondition = subscription.status.conditions.find(condition => condition.type === 'InstallPlanPending' && condition.status === 'True')
               if (installCondition) {
                 ctx.installPlanName = subscription.status.installplan.name
-                task.title = `${task.title}...done.`
+                task.title = `${task.title}...[OK]`
                 return
               }
             }
@@ -311,7 +308,7 @@ export class OLMTasks {
         enabled: (ctx: any) => ctx.installPlanName,
         task: async (ctx: any, task: any) => {
           await kube.approveOperatorInstallationPlan(ctx.installPlanName, ctx.operatorNamespace)
-          task.title = `${task.title}...done.`
+          task.title = `${task.title}...[OK]`
         },
       },
       {
@@ -320,7 +317,7 @@ export class OLMTasks {
         task: async (ctx: any, task: any) => {
           await kube.waitUntilOperatorIsInstalled(ctx.installPlanName, ctx.operatorNamespace, 60)
           ctx.highlightedMessages.push(`Operator is updated from ${ctx.currentVersion} to ${ctx.nextVersion} version`)
-          task.title = `${task.title}...done.`
+          task.title = `${task.title}...[OK]`
         },
       },
       patchingEclipseCheCluster(flags, kube, command),
@@ -335,7 +332,7 @@ export class OLMTasks {
         title: 'Check if OLM is pre-installed on the platform',
         task: async (ctx: any, task: any) => {
           ctx.isPreInstalledOLM = Boolean(await kube.isPreInstalledOLM())
-          task.title = `${task.title}: ${ctx.isPreInstalledOLM}...OK`
+          task.title = `${task.title}: ${ctx.isPreInstalledOLM}...[OK]`
         },
       },
       {
@@ -345,10 +342,10 @@ export class OLMTasks {
           if (subscription) {
             ctx.subscriptionName = subscription.metadata.name
             ctx.operatorNamespace = subscription.metadata.namespace
-            task.title = `${task.title}...Found ${ctx.subscriptionName}`
+            task.title = `${task.title}...[Found ${ctx.subscriptionName}]`
           } else {
             ctx.operatorNamespace = flags.chenamespace || DEFAULT_CHE_NAMESPACE
-            task.title = `${task.title}...Not Found`
+            task.title = `${task.title}...[Not Found]`
           }
           // Also get operator group here, because if delete subscription and csv we'll lose the link to it
           ctx.operatorGroup = await che.findCheOperatorOperatorGroup(ctx.operatorNamespace)
@@ -359,7 +356,7 @@ export class OLMTasks {
         enabled: ctx => ctx.isPreInstalledOLM && ctx.subscriptionName,
         task: async (ctx: any, task: any) => {
           await kube.deleteOperatorSubscription(ctx.subscriptionName, ctx.operatorNamespace)
-          task.title = `${task.title}...OK`
+          task.title = `${task.title}...[OK]`
         },
       },
       {
@@ -371,7 +368,7 @@ export class OLMTasks {
           for (const csv of csvsToDelete) {
             await kube.deleteClusterServiceVersion(ctx.operatorNamespace, csv.metadata.name!)
           }
-          task.title = `${task.title}...OK`
+          task.title = `${task.title}...[OK]`
         },
       },
       {
@@ -383,35 +380,35 @@ export class OLMTasks {
           if (opgr && opgr.metadata && opgr.metadata.name && opgr.metadata.namespace) {
             await kube.deleteOperatorGroup(opgr.metadata.name, opgr.metadata.namespace)
           }
-          task.title = `${task.title}...OK`
+          task.title = `${task.title}...[OK]`
         },
       },
       {
         title: TASK_TITLE_DELETE_CUSTOM_CATALOG_SOURCE,
         task: async (ctx: any, task: any) => {
           await kube.deleteCatalogSource(ctx.operatorNamespace, CUSTOM_CATALOG_SOURCE_NAME)
-          task.title = `${task.title}...OK`
+          task.title = `${task.title}...[OK]`
         },
       },
       {
         title: TASK_TITLE_DELETE_NIGHTLY_CATALOG_SOURCE,
         task: async (ctx: any, task: any) => {
           await kube.deleteCatalogSource(ctx.operatorNamespace, NEXT_CATALOG_SOURCE_NAME)
-          task.title = `${task.title}...OK`
+          task.title = `${task.title}...[OK]`
         },
       },
       {
         title: `Delete role ${this.prometheusRoleName}`,
         task: async (_ctx: any, task: any) => {
           await kube.deleteRole(this.prometheusRoleName, flags.chenamespace)
-          task.title = `${task.title}...OK`
+          task.title = `${task.title}...[OK]`
         },
       },
       {
         title: `Delete role binding ${this.prometheusRoleName}`,
         task: async (_ctx: any, task: any) => {
           await kube.deleteRoleBinding(this.prometheusRoleName, flags.chenamespace)
-          task.title = `${task.title}...OK`
+          task.title = `${task.title}...[OK]`
         },
       },
     ]
@@ -426,7 +423,7 @@ export class OLMTasks {
           cli.url('install.sh', 'https://raw.githubusercontent.com/operator-framework/operator-lifecycle-manager/master/deploy/upstream/quickstart/install.sh')
           command.error('OLM is required for installation of CodeReady Workspaces with installer flag \'olm\'')
         }
-        task.title = `${task.title}...done.`
+        task.title = `${task.title}...[OK]`
       },
     }
   }
